@@ -11,7 +11,9 @@ for which a new license (GPL+exception) is in place.
 #include <QDialog>
 #include <QTextStream>
 #include <QSqlTableModel>
+
 #include "ui_dataexportdialog.h"
+#include "sqlmodels.h"
 
 class DataViewer;
 class QProgressDialog;
@@ -31,7 +33,7 @@ class DataExportDialog : public QDialog
 
 	private:
 		bool cancelled;
-		QSqlTableModel * m_data;
+		SqlTableModel * m_data;
 		QStringList m_header;
 		QProgressDialog * progress;
 
