@@ -17,7 +17,7 @@ class QTextEdit;
 class QToolBar;
 class QAction;
 class QSplitter;
-class QSqlTableModel;
+class SqlTableModel;
 
 
 /*! \brief A Complex widget handling the database outputs and status messages.
@@ -30,8 +30,10 @@ class DataViewer : public QMainWindow
 		DataViewer(QWidget * parent = 0);
 		~DataViewer(){};
 
-		//! \brief Set data model. See Qt model/view documentation.
-		void setTableModel(QAbstractItemModel * model);
+		/*! \brief Set data model. See Qt model/view documentation.
+		\retval bool true when the model is set succesfully
+		*/
+		bool setTableModel(QAbstractItemModel * model);
 		//! \brief Set text to the status widget.
 		void setStatusText(const QString & text);
 		//! \brief Show/hide status widget
@@ -39,7 +41,7 @@ class DataViewer : public QMainWindow
 		//! \brief Show/hide action tools
 		void showButtons(bool show);
 
-		QSqlTableModel* tableData();
+		SqlTableModel* tableData();
 		QStringList tableHeader();
 
 		QByteArray saveSplitter() { return ui.splitter->saveState(); };
@@ -47,7 +49,6 @@ class DataViewer : public QMainWindow
 
 	private:
 		Ui::DataViewer ui;
-		bool modified;
 
 	private slots:
 		void addRow();
