@@ -35,19 +35,26 @@ class TableEditorDialog : public QDialog
 
 		DatabaseTableField getColumn(int row);
 
+		/*! \brief Gues what default value should be set.
+		If there is a successful conversion to the number,
+		default(foo) is used = no change for string.
+		If there is a "'" at the first place - default(foo)
+		is used = no change for string.
+		Else use default('foo') = add SQL string mark.
+		*/
+		QString getDefaultClause(const QString & defVal);
+
 	public slots:
 		virtual void addField();
 		virtual void removeField();
 		virtual void fieldSelected();
 		virtual void nameEdit_textChanged(const QString&);
 		virtual void createButton_clicked();
+		virtual void tabWidget_currentChanged(int index);
 
 	private:
 		QComboBox * makeTypeBox();
 		SqlHighlighter * highlighter;
-
-	private slots:
-		void tabWidget_currentChanged(int index);
 };
 
 #endif
